@@ -7,6 +7,7 @@ import jwt
 import urllib #Needed for avoiding using requests, which modified the S3 presigned URL
 
 from .utils import convert_timestamps, send_post_request, send_get_request, decode_jwt_token, querystr_to_json, att2statement
+from .lineage_graph import create_lineage_graph 
 
 from .constants import (
     SCRIBE_VULNERABILITIES_DATASET,
@@ -1033,12 +1034,24 @@ class ScribeClient:
                 return f"{title}\n{self.format_query_result_table(r)}"
         return "Error running query"
 
-    def query_lineage(self, querystr, title="") -> str:
+    def query_lineage(self, querystr, title="", graph_filename=None) -> str:
         logging.debug(f"Query lineage with: {querystr}")
         query = self.querystr_to_json(querystr)
         if query:
             r = self.query_superset(self.scribe_lineage_dataset, query, time_tokens=["timestamp"])
             if r:
+                if graph_filename:
+                    required_fields = ["asset_name", "asset_type", "parent_name", "parent_type", "external_id", "parent_external_id", "uri"]
+                    columns = query.get("columns", [])
+                    if not all(field in columns for field in required_fields):
+                        logging.error(f"Query must include the following fields: {', '.join(required_fields)}")
+                        return "Error: Query must include required fields for lineage graph generation."
+                    
+                    lineage_data = r["result"][0]["data"]
+                    full_path_filename = create_lineage_graph(lineage_data, output_file=graph_filename)
+                    logging.info(f"Lineage graph saved to {full_path_filename}")
+                else:
+                    logging.warning("No graph filename provided, lineage graph will not be generated.")
                 return f"{title}\n{self.format_query_result_table(r)}"
         return "Error running query"
     
